@@ -8,5 +8,5 @@ Pattern mining algorithms for the Python ecosystem
 # joblib currently disable logging inside delayed functions
 __author__ = """scikit-mine team"""
 __email__ = """remi.adon@gmail.com"""
-__version__ = '0.0.1'  # pylint: disable= undefined-variable, pointless-statement
-__credits__ = 'Centre Inria Rennes - Bretagne Atlantique'
+__version__ = "0.0.3"  # pylint: disable= undefined-variable, pointless-statement
+__credits__ = "Centre Inria Rennes - Bretagne Atlantique"
