@@ -4,8 +4,6 @@ Bitmap definition for scikit-mine
 import platform
 
 from sortedcontainers import SortedSet
-from roaringbitmap import RoaringBitmap as _RB
-
 
 
 class BitmapMock(SortedSet):  # pylint: disable=too-many-ancestors
@@ -15,6 +13,7 @@ class BitmapMock(SortedSet):  # pylint: disable=too-many-ancestors
     This inherits the ``SortedSet`` class and provide some extra functions
     to ensure compatibility with other -performant- bitmap implementations
     """
+
     def intersection_len(self, other):
         """Returns length of the intersection"""
         return len(self & other)
@@ -28,12 +27,15 @@ class BitmapMock(SortedSet):  # pylint: disable=too-many-ancestors
                 self.add(e)
 
     def __repr__(self):
-        return '[{}]'.format(', '.join(map(str, self)))
+        return "[{}]".format(", ".join(map(str, self)))
+
+    max = lambda self: self[-1]
+    min = lambda self: self[0]
 
     __str__ = __repr__
 
 
-if platform.system() == 'Windows':
+if platform.system() == "Windows":
     Bitmap = BitmapMock
 else:
-    Bitmap = _RB
+    from roaringbitmap import RoaringBitmap as Bitmap  # pylint: disable= unused-import
