@@ -9,11 +9,13 @@ import pandas as pd
 from .conf import urlopen
 from ._base import get_data_home
 
-BASE_URL = 'http://fimi.uantwerpen.be/data/'
+BASE_URL = "http://fimi.uantwerpen.be/data/"
+
 
 def _preprocess(transaction):
     s = bytes.decode(transaction[:-2])
-    return s.split(' ')
+    return s.split(" ")
+
 
 def fetch_any(filename, data_home=None):
     """Base loader for all datasets from the FIMI repository
@@ -40,7 +42,7 @@ def fetch_any(filename, data_home=None):
     filepath = os.path.join(data_home, filename)
     if filename in os.listdir(data_home):  # already fetched
         s = pd.read_pickle(filepath)
-    else:                                  # not fetched yet
+    else:  # not fetched yet
         url = BASE_URL + filename
         resp = urlopen(url)
         it = (_preprocess(transaction) for transaction in resp)
@@ -48,11 +50,14 @@ def fetch_any(filename, data_home=None):
         s = pd.Series(it, name=name)
         s.to_pickle(filepath)
 
-    try: s = s.map(lambda l: list(map(int, l)))
-    except ValueError: pass
+    try:
+        s = s.map(lambda l: list(map(int, l)))
+    except ValueError:
+        pass
 
     return s
 
+
 def fetch_chess(data_home=None):
     """Fetch and return the chess dataset (Frequent Itemset Mining)
 
@@ -75,7 +80,7 @@ def fetch_chess(data_home=None):
         Transactions from the chess dataset, as an in-memory pandas Series.
         Each unique transaction is represented as a Python list.
     """
-    return fetch_any('chess.dat', data_home=data_home)
+    return fetch_any("chess.dat", data_home=data_home)
 
 
 def fetch_connect(data_home=None):
@@ -100,10 +105,10 @@ def fetch_connect(data_home=None):
         Transactions from the connect dataset, as an in-memory pandas Series.
         Each unique transaction is represented as a Python list.
     """
-    return fetch_any('connect.dat', data_home=data_home)
+    return fetch_any("connect.dat", data_home=data_home)
 
 
-def fetch_mushroom(data_home=None):
+def fetch_mushroom(data_home=None, return_D_y=False):
     """Fetch and return the mushroom dataset (Frequent Itemset Mining)
 
     The Mushroom data set includes descriptions of hypothetical samples corresponding
@@ -113,13 +118,13 @@ def fetch_mushroom(data_home=None):
     4208 (51.8%) are edible and 3916 (48.2%) are poisonous.
 
     The data contains 22 nomoinal features plus the class attribure (edible or not).
-    These features were translated into 114 items.
+    These features were translated into 117 items.
 
     ====================   ==============
-    Nb of items                       119
+    Nb of items                       117
     Nb of transactions               8124
-    Avg transaction size             23.0
-    Density                         0.193
+    Avg transaction size             22.0
+    Density                         0.188
     ====================   ==============
 
     Parameters
@@ -128,13 +133,39 @@ def fetch_mushroom(data_home=None):
         Specify another download and cache folder for the datasets. By default
         all scikit-mine data is stored in `scikit-mine_data`.
 
+    return_D_y: bool, default=False.
+        If True, returns a tuple for both the data and the associated labels
+        (0 for edible, 1 for poisonous)
+
     Returns
     -------
-    pd.Series
+    D: pd.Series
         Transactions from the mushroom dataset, as an in-memory pandas Series.
         Each unique transaction is represented as a Python list.
+
+    (D, y) : tuple
+        if ``return_D_y`` is True
+
+    Examples
+    --------
+    >>> from skmine.datasets.fimi import fetch_mushroom
+    >>> from skmine.datasets.utils import describe
+    >>> D, y = fetch_mushroom(return_D_y=True)
+    >>> describe(D)['n_items']
+    117
+    >>> y.value_counts()
+    0    4208
+    1    3916
+    Name: mushroom, dtype: int64
     """
-    return fetch_any('mushroom.dat', data_home=data_home)
+    mush = fetch_any("mushroom.dat", data_home=data_home)
+    D = mush.str[1:]
+    if return_D_y:
+        y = mush.str[0]
+        y = y.replace(2, 0)  # 2 is edible, 1 is poisonous
+        return D, y
+
+    return D
 
 
 def fetch_pumsb(data_home=None):
@@ -161,7 +192,7 @@ def fetch_pumsb(data_home=None):
         Transactions from the pumsb dataset, as an in-memory pandas Series.
         Each unique transaction is represented as a Python list.
     """
-    return fetch_any('pumsb.dat', data_home=data_home)
+    return fetch_any("pumsb.dat", data_home=data_home)
 
 
 def fetch_pumsb_star(data_home=None):
@@ -186,7 +217,7 @@ def fetch_pumsb_star(data_home=None):
         Transactions from the pumsb_star dataset, as an in-memory pandas Series.
         Each unique transaction is represented as a Python list.
     """
-    return fetch_any('pumsb_star.dat', data_home=data_home)
+    return fetch_any("pumsb_star.dat", data_home=data_home)
 
 
 def fetch_kosarak(data_home=None):
@@ -213,7 +244,7 @@ def fetch_kosarak(data_home=None):
         Transactions from the kosarak dataset, as an in-memory pandas Series.
         Each unique transaction is represented as a Python list.
     """
-    return fetch_any('kosarak.dat', data_home=data_home)
+    return fetch_any("kosarak.dat", data_home=data_home)
 
 
 def fetch_retail(data_home=None):
@@ -249,7 +280,8 @@ def fetch_retail(data_home=None):
         Transactions from the retail dataset, as an in-memory pandas Series.
         Each unique transaction is represented as a Python list.
     """
-    return fetch_any('retail.dat', data_home=data_home)
+    return fetch_any("retail.dat", data_home=data_home)
+
 
 def fetch_accidents(data_home=None):
     """Fetch and return the accidents dataset (Frequent Itemset Mining)
@@ -278,4 +310,4 @@ def fetch_accidents(data_home=None):
         Each unique transaction is represented as a Python list.
 
     """
-    return fetch_any('accidents.dat', data_home=data_home)
+    return fetch_any("accidents.dat", data_home=data_home)
